@@ -104,6 +104,18 @@ def ConstructCreateRequestFromArgsAlpha(
   )
 
 
+def ConstructCreateMachineConfigFromArgs(alloydb_messages, args):
+  """Validates command line input arguments and creates a MachineConfig object."""
+  if args.cpu_count or args.machine_type:
+    return alloydb_messages.MachineConfig(
+        cpuCount=args.cpu_count, machineType=args.machine_type
+    )
+  else:
+    raise DetailedArgumentError(
+        'Either --cpu-count or --machine-type must be specified.'
+    )
+
+
 def _ConstructInstanceFromArgs(client, alloydb_messages, args):
   """Validates command line input arguments and passes parent's resources to create an AlloyDB instance.
 
@@ -121,8 +133,8 @@ def _ConstructInstanceFromArgs(client, alloydb_messages, args):
   instance_resource.availabilityType = ParseAvailabilityType(
       alloydb_messages, args.availability_type
   )
-  instance_resource.machineConfig = alloydb_messages.MachineConfig(
-      cpuCount=args.cpu_count, machineType=args.machine_type
+  instance_resource.machineConfig = ConstructCreateMachineConfigFromArgs(
+      alloydb_messages, args
   )
   instance_ref = client.resource_parser.Create(
       'alloydb.projects.locations.clusters.instances',
@@ -373,11 +385,15 @@ def ConstructInstanceAndUpdatePathsFromArgs(
   insights_config_record_client_address_path = (
       'queryInsightsConfig.recordClientAddress'
   )
+  activation_policy_path = 'activationPolicy'
 
   instance_resource = alloydb_messages.Instance()
   paths = []
 
   instance_resource.name = instance_ref.RelativeName()
+  if args.activation_policy:
+    instance_resource.activationPolicy = args.activation_policy
+    paths.append(activation_policy_path)
 
   availability_type = ParseAvailabilityType(
       alloydb_messages, args.availability_type
@@ -1026,11 +1042,6 @@ def ConstructPatchRequestFromArgsAlpha(alloydb_messages, instance_ref, args):
       alloydb_messages, instance_ref, args
   )
 
-  activation_policy_path = 'activationPolicy'
-  if args.activation_policy:
-    instance_resource.activationPolicy = args.activation_policy
-    paths.append(activation_policy_path)
-
   mask = ','.join(paths) if paths else None
 
   return alloydb_messages.AlloydbProjectsLocationsClustersInstancesPatchRequest(
